# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: places.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'places.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cplaces.proto\x12\x06places\"H\n\x12\x43reatePlaceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\'\n\x13\x43reatePlaceResponse\x12\x10\n\x08place_id\x18\x01 \x01(\t\"4\n\x0fGetPlaceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\"h\n\x10GetPlaceResponse\x12\x10\n\x08place_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x1f\n\tuser_role\x18\x04 \x01(\x0e\x32\x0c.places.Role\"$\n\x11ListPlacesRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\":\n\x12ListPlacesResponse\x12$\n\x06places\x18\x01 \x03(\x0b\x32\x14.places.PlaceSummary\"d\n\x0cPlaceSummary\x12\x10\n\x08place_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x1f\n\tuser_role\x18\x04 \x01(\x0e\x32\x0c.places.Role\"Z\n\x12UpdatePlaceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"\'\n\x13UpdatePlaceResponse\x12\x10\n\x08place_id\x18\x01 \x01(\t\"7\n\x12\x44\x65letePlaceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\"&\n\x13\x44\x65letePlaceResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"i\n\x10\x41\x64\x64MemberRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x16\n\x0etarget_user_id\x18\x03 \x01(\t\x12\x1a\n\x04role\x18\x04 \x01(\x0e\x32\x0c.places.Role\"$\n\x11\x41\x64\x64MemberResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"P\n\x13RemoveMemberRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x16\n\x0etarget_user_id\x18\x03 \x01(\t\"\'\n\x14RemoveMemberResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"p\n\x17UpdateMemberRoleRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x16\n\x0etarget_user_id\x18\x03 \x01(\t\x12\x1a\n\x04role\x18\x04 \x01(\x0e\x32\x0c.places.Role\"+\n\x18UpdateMemberRoleResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"7\n\x12ListMembersRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\":\n\x13ListMembersResponse\x12#\n\x07members\x18\x01 \x03(\x0b\x32\x12.places.MemberInfo\"9\n\nMemberInfo\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x1a\n\x04role\x18\x02 \x01(\x0e\x32\x0c.places.Role*M\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\x0e\n\nROLE_OWNER\x10\x01\x12\x0e\n\nROLE_ADMIN\x10\x02\x12\x0f\n\x0bROLE_VIEWER\x10\x03\x32\x97\x05\n\rPlacesService\x12\x46\n\x0b\x43reatePlace\x12\x1a.places.CreatePlaceRequest\x1a\x1b.places.CreatePlaceResponse\x12=\n\x08GetPlace\x12\x17.places.GetPlaceRequest\x1a\x18.places.GetPlaceResponse\x12\x43\n\nListPlaces\x12\x19.places.ListPlacesRequest\x1a\x1a.places.ListPlacesResponse\x12\x46\n\x0bUpdatePlace\x12\x1a.places.UpdatePlaceRequest\x1a\x1b.places.UpdatePlaceResponse\x12\x46\n\x0b\x44\x65letePlace\x12\x1a.places.DeletePlaceRequest\x1a\x1b.places.DeletePlaceResponse\x12@\n\tAddMember\x12\x18.places.AddMemberRequest\x1a\x19.places.AddMemberResponse\x12I\n\x0cRemoveMember\x12\x1b.places.RemoveMemberRequest\x1a\x1c.places.RemoveMemberResponse\x12U\n\x10UpdateMemberRole\x12\x1f.places.UpdateMemberRoleRequest\x1a .places.UpdateMemberRoleResponse\x12\x46\n\x0bListMembers\x12\x1a.places.ListMembersRequest\x1a\x1b.places.ListMembersResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'places_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ROLE']._serialized_start=1332
  _globals['_ROLE']._serialized_end=1409
  _globals['_CREATEPLACEREQUEST']._serialized_start=24
  _globals['_CREATEPLACEREQUEST']._serialized_end=96
  _globals['_CREATEPLACERESPONSE']._serialized_start=98
  _globals['_CREATEPLACERESPONSE']._serialized_end=137
  _globals['_GETPLACEREQUEST']._serialized_start=139
  _globals['_GETPLACEREQUEST']._serialized_end=191
  _globals['_GETPLACERESPONSE']._serialized_start=193
  _globals['_GETPLACERESPONSE']._serialized_end=297
  _globals['_LISTPLACESREQUEST']._serialized_start=299
  _globals['_LISTPLACESREQUEST']._serialized_end=335
  _globals['_LISTPLACESRESPONSE']._serialized_start=337
  _globals['_LISTPLACESRESPONSE']._serialized_end=395
  _globals['_PLACESUMMARY']._serialized_start=397
  _globals['_PLACESUMMARY']._serialized_end=497
  _globals['_UPDATEPLACEREQUEST']._serialized_start=499
  _globals['_UPDATEPLACEREQUEST']._serialized_end=589
  _globals['_UPDATEPLACERESPONSE']._serialized_start=591
  _globals['_UPDATEPLACERESPONSE']._serialized_end=630
  _globals['_DELETEPLACEREQUEST']._serialized_start=632
  _globals['_DELETEPLACEREQUEST']._serialized_end=687
  _globals['_DELETEPLACERESPONSE']._serialized_start=689
  _globals['_DELETEPLACERESPONSE']._serialized_end=727
  _globals['_ADDMEMBERREQUEST']._serialized_start=729
  _globals['_ADDMEMBERREQUEST']._serialized_end=834
  _globals['_ADDMEMBERRESPONSE']._serialized_start=836
  _globals['_ADDMEMBERRESPONSE']._serialized_end=872
  _globals['_REMOVEMEMBERREQUEST']._serialized_start=874
  _globals['_REMOVEMEMBERREQUEST']._serialized_end=954
  _globals['_REMOVEMEMBERRESPONSE']._serialized_start=956
  _globals['_REMOVEMEMBERRESPONSE']._serialized_end=995
  _globals['_UPDATEMEMBERROLEREQUEST']._serialized_start=997
  _globals['_UPDATEMEMBERROLEREQUEST']._serialized_end=1109
  _globals['_UPDATEMEMBERROLERESPONSE']._serialized_start=1111
  _globals['_UPDATEMEMBERROLERESPONSE']._serialized_end=1154
  _globals['_LISTMEMBERSREQUEST']._serialized_start=1156
  _globals['_LISTMEMBERSREQUEST']._serialized_end=1211
  _globals['_LISTMEMBERSRESPONSE']._serialized_start=1213
  _globals['_LISTMEMBERSRESPONSE']._serialized_end=1271
  _globals['_MEMBERINFO']._serialized_start=1273
  _globals['_MEMBERINFO']._serialized_end=1330
  _globals['_PLACESSERVICE']._serialized_start=1412
  _globals['_PLACESSERVICE']._serialized_end=2075
# @@protoc_insertion_point(module_scope)
