"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import places_pb2
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class PlacesServiceStub:
    @typing.overload
    def __new__(cls, channel: grpc.Channel) -> PlacesServiceStub: ...
    @typing.overload
    def __new__(cls, channel: grpc.aio.Channel) -> PlacesServiceAsyncStub: ...
    CreatePlace: grpc.UnaryUnaryMultiCallable[places_pb2.CreatePlaceRequest, places_pb2.CreatePlaceResponse]
    """Places CRUD"""
    GetPlace: grpc.UnaryUnaryMultiCallable[places_pb2.GetPlaceRequest, places_pb2.GetPlaceResponse]
    ListPlaces: grpc.UnaryUnaryMultiCallable[places_pb2.ListPlacesRequest, places_pb2.ListPlacesResponse]
    UpdatePlace: grpc.UnaryUnaryMultiCallable[places_pb2.UpdatePlaceRequest, places_pb2.UpdatePlaceResponse]
    DeletePlace: grpc.UnaryUnaryMultiCallable[places_pb2.DeletePlaceRequest, places_pb2.DeletePlaceResponse]
    AddMember: grpc.UnaryUnaryMultiCallable[places_pb2.AddMemberRequest, places_pb2.AddMemberResponse]
    """Members"""
    RemoveMember: grpc.UnaryUnaryMultiCallable[places_pb2.RemoveMemberRequest, places_pb2.RemoveMemberResponse]
    UpdateMemberRole: grpc.UnaryUnaryMultiCallable[places_pb2.UpdateMemberRoleRequest, places_pb2.UpdateMemberRoleResponse]
    ListMembers: grpc.UnaryUnaryMultiCallable[places_pb2.ListMembersRequest, places_pb2.ListMembersResponse]

@typing.type_check_only
class PlacesServiceAsyncStub(PlacesServiceStub):
    def __init__(self, channel: grpc.aio.Channel) -> None: ...
    CreatePlace: grpc.aio.UnaryUnaryMultiCallable[places_pb2.CreatePlaceRequest, places_pb2.CreatePlaceResponse]  # type: ignore[assignment]
    """Places CRUD"""
    GetPlace: grpc.aio.UnaryUnaryMultiCallable[places_pb2.GetPlaceRequest, places_pb2.GetPlaceResponse]  # type: ignore[assignment]
    ListPlaces: grpc.aio.UnaryUnaryMultiCallable[places_pb2.ListPlacesRequest, places_pb2.ListPlacesResponse]  # type: ignore[assignment]
    UpdatePlace: grpc.aio.UnaryUnaryMultiCallable[places_pb2.UpdatePlaceRequest, places_pb2.UpdatePlaceResponse]  # type: ignore[assignment]
    DeletePlace: grpc.aio.UnaryUnaryMultiCallable[places_pb2.DeletePlaceRequest, places_pb2.DeletePlaceResponse]  # type: ignore[assignment]
    AddMember: grpc.aio.UnaryUnaryMultiCallable[places_pb2.AddMemberRequest, places_pb2.AddMemberResponse]  # type: ignore[assignment]
    """Members"""
    RemoveMember: grpc.aio.UnaryUnaryMultiCallable[places_pb2.RemoveMemberRequest, places_pb2.RemoveMemberResponse]  # type: ignore[assignment]
    UpdateMemberRole: grpc.aio.UnaryUnaryMultiCallable[places_pb2.UpdateMemberRoleRequest, places_pb2.UpdateMemberRoleResponse]  # type: ignore[assignment]
    ListMembers: grpc.aio.UnaryUnaryMultiCallable[places_pb2.ListMembersRequest, places_pb2.ListMembersResponse]  # type: ignore[assignment]

class PlacesServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreatePlace(
        self,
        request: places_pb2.CreatePlaceRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.CreatePlaceResponse, collections.abc.Awaitable[places_pb2.CreatePlaceResponse]]:
        """Places CRUD"""

    @abc.abstractmethod
    def GetPlace(
        self,
        request: places_pb2.GetPlaceRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.GetPlaceResponse, collections.abc.Awaitable[places_pb2.GetPlaceResponse]]: ...

    @abc.abstractmethod
    def ListPlaces(
        self,
        request: places_pb2.ListPlacesRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.ListPlacesResponse, collections.abc.Awaitable[places_pb2.ListPlacesResponse]]: ...

    @abc.abstractmethod
    def UpdatePlace(
        self,
        request: places_pb2.UpdatePlaceRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.UpdatePlaceResponse, collections.abc.Awaitable[places_pb2.UpdatePlaceResponse]]: ...

    @abc.abstractmethod
    def DeletePlace(
        self,
        request: places_pb2.DeletePlaceRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.DeletePlaceResponse, collections.abc.Awaitable[places_pb2.DeletePlaceResponse]]: ...

    @abc.abstractmethod
    def AddMember(
        self,
        request: places_pb2.AddMemberRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.AddMemberResponse, collections.abc.Awaitable[places_pb2.AddMemberResponse]]:
        """Members"""

    @abc.abstractmethod
    def RemoveMember(
        self,
        request: places_pb2.RemoveMemberRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.RemoveMemberResponse, collections.abc.Awaitable[places_pb2.RemoveMemberResponse]]: ...

    @abc.abstractmethod
    def UpdateMemberRole(
        self,
        request: places_pb2.UpdateMemberRoleRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.UpdateMemberRoleResponse, collections.abc.Awaitable[places_pb2.UpdateMemberRoleResponse]]: ...

    @abc.abstractmethod
    def ListMembers(
        self,
        request: places_pb2.ListMembersRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.ListMembersResponse, collections.abc.Awaitable[places_pb2.ListMembersResponse]]: ...

def add_PlacesServiceServicer_to_server(servicer: PlacesServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
