# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: devices.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'devices.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rdevices.proto\x12\x07\x64\x65vices\"\xf4\x01\n\nDeviceInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12%\n\x06status\x18\x04 \x01(\x0e\x32\x15.devices.DeviceStatus\x12\x14\n\x0clast_seen_at\x18\x05 \x01(\t\x12\x12\n\ncreated_at\x18\x06 \x01(\t\x12\x12\n\nupdated_at\x18\x07 \x01(\t\x12$\n\x07sensors\x18\x08 \x03(\x0b\x32\x13.devices.SensorInfo\x12(\n\tactuators\x18\t \x03(\x0b\x32\x15.devices.ActuatorInfo\"\x7f\n\rDeviceSummary\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12%\n\x06status\x18\x04 \x01(\x0e\x32\x15.devices.DeviceStatus\x12\x14\n\x0clast_seen_at\x18\x05 \x01(\t\"F\n\x13\x43reateDeviceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"8\n\x14\x43reateDeviceResponse\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"H\n\x10GetDeviceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\"8\n\x11GetDeviceResponse\x12#\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x13.devices.DeviceInfo\"W\n\x12ListDevicesRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x10\n\x08per_page\x18\x04 \x01(\x05\"M\n\x13ListDevicesResponse\x12\'\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x16.devices.DeviceSummary\x12\r\n\x05total\x18\x02 \x01(\x05\"Y\n\x13UpdateDeviceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\")\n\x14UpdateDeviceResponse\x12\x11\n\tdevice_id\x18\x01 \x01(\t\"K\n\x13\x44\x65leteDeviceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\"\'\n\x14\x44\x65leteDeviceResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"T\n\x1cRegenerateDeviceTokenRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\".\n\x1dRegenerateDeviceTokenResponse\x12\r\n\x05token\x18\x01 \x01(\t\"\x9c\x01\n\nSensorInfo\x12\x11\n\tsensor_id\x18\x01 \x01(\t\x12\x11\n\tdevice_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12&\n\nvalue_type\x18\x05 \x01(\x0e\x32\x12.devices.ValueType\x12\x12\n\nunit_label\x18\x06 \x01(\t\x12\x11\n\tprecision\x18\x07 \x01(\x05\"\xb5\x01\n\x13\x43reateSensorRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12&\n\nvalue_type\x18\x06 \x01(\x0e\x32\x12.devices.ValueType\x12\x12\n\nunit_label\x18\x07 \x01(\t\x12\x11\n\tprecision\x18\x08 \x01(\x05\")\n\x14\x43reateSensorResponse\x12\x11\n\tsensor_id\x18\x01 \x01(\t\"J\n\x12ListSensorsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\";\n\x13ListSensorsResponse\x12$\n\x07sensors\x18\x01 \x03(\x0b\x32\x13.devices.SensorInfo\"\x93\x01\n\x13UpdateSensorRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x11\n\tsensor_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x12\n\nunit_label\x18\x06 \x01(\t\x12\x11\n\tprecision\x18\x07 \x01(\x05\")\n\x14UpdateSensorResponse\x12\x11\n\tsensor_id\x18\x01 \x01(\t\"^\n\x13\x44\x65leteSensorRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x11\n\tsensor_id\x18\x04 \x01(\t\"\'\n\x14\x44\x65leteSensorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x9b\x01\n\rThresholdInfo\x12\x14\n\x0cthreshold_id\x18\x01 \x01(\t\x12\x11\n\tsensor_id\x18\x02 \x01(\t\x12$\n\x04type\x18\x03 \x01(\x0e\x32\x16.devices.ThresholdType\x12\r\n\x05value\x18\x04 \x01(\x01\x12,\n\x08severity\x18\x05 \x01(\x0e\x32\x1a.devices.ThresholdSeverity\"\xc1\x01\n\x13SetThresholdRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x11\n\tsensor_id\x18\x04 \x01(\t\x12$\n\x04type\x18\x05 \x01(\x0e\x32\x16.devices.ThresholdType\x12\r\n\x05value\x18\x06 \x01(\x01\x12,\n\x08severity\x18\x07 \x01(\x0e\x32\x1a.devices.ThresholdSeverity\",\n\x14SetThresholdResponse\x12\x14\n\x0cthreshold_id\x18\x01 \x01(\t\"`\n\x15ListThresholdsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x11\n\tsensor_id\x18\x04 \x01(\t\"D\n\x16ListThresholdsResponse\x12*\n\nthresholds\x18\x01 \x03(\x0b\x32\x16.devices.ThresholdInfo\"w\n\x16\x44\x65leteThresholdRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x11\n\tsensor_id\x18\x04 \x01(\t\x12\x14\n\x0cthreshold_id\x18\x05 \x01(\t\"*\n\x17\x44\x65leteThresholdResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"/\n\x1aGetSensorThresholdsRequest\x12\x11\n\tsensor_id\x18\x01 \x01(\t\"I\n\x1bGetSensorThresholdsResponse\x12*\n\nthresholds\x18\x01 \x03(\x0b\x32\x16.devices.ThresholdInfo\"\xea\x01\n\x0c\x41\x63tuatorInfo\x12\x13\n\x0b\x61\x63tuator_id\x18\x01 \x01(\t\x12\x11\n\tdevice_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12&\n\nvalue_type\x18\x05 \x01(\x0e\x32\x12.devices.ValueType\x12\x12\n\nunit_label\x18\x06 \x01(\t\x12\x11\n\tprecision\x18\x07 \x01(\x05\x12\x11\n\tmin_value\x18\x08 \x01(\x01\x12\x11\n\tmax_value\x18\t \x01(\x01\x12\x0c\n\x04step\x18\n \x01(\x01\x12\x14\n\x0c\x65num_options\x18\x0b \x03(\t\"\x81\x02\n\x15\x43reateActuatorRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12&\n\nvalue_type\x18\x06 \x01(\x0e\x32\x12.devices.ValueType\x12\x12\n\nunit_label\x18\x07 \x01(\t\x12\x11\n\tprecision\x18\x08 \x01(\x05\x12\x11\n\tmin_value\x18\t \x01(\x01\x12\x11\n\tmax_value\x18\n \x01(\x01\x12\x0c\n\x04step\x18\x0b \x01(\x01\x12\x14\n\x0c\x65num_options\x18\x0c \x03(\t\"-\n\x16\x43reateActuatorResponse\x12\x13\n\x0b\x61\x63tuator_id\x18\x01 \x01(\t\"L\n\x14ListActuatorsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\"A\n\x15ListActuatorsResponse\x12(\n\tactuators\x18\x01 \x03(\x0b\x32\x15.devices.ActuatorInfo\"\xe1\x01\n\x15UpdateActuatorRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x13\n\x0b\x61\x63tuator_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x12\n\nunit_label\x18\x06 \x01(\t\x12\x11\n\tprecision\x18\x07 \x01(\x05\x12\x11\n\tmin_value\x18\x08 \x01(\x01\x12\x11\n\tmax_value\x18\t \x01(\x01\x12\x0c\n\x04step\x18\n \x01(\x01\x12\x14\n\x0c\x65num_options\x18\x0b \x03(\t\"-\n\x16UpdateActuatorResponse\x12\x13\n\x0b\x61\x63tuator_id\x18\x01 \x01(\t\"b\n\x15\x44\x65leteActuatorRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x13\n\x0b\x61\x63tuator_id\x18\x04 \x01(\t\")\n\x16\x44\x65leteActuatorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"o\n\x12SendCommandRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x63tuator_key\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\"&\n\x13SendCommandResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"?\n\x19\x41uthenticateDeviceRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"+\n\x1a\x41uthenticateDeviceResponse\x12\r\n\x05\x61llow\x18\x01 \x01(\x08\"H\n\x15\x43heckDeviceAclRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\"\'\n\x16\x43heckDeviceAclResponse\x12\r\n\x05\x61llow\x18\x01 \x01(\x08\"1\n\x1eGenerateMqttCredentialsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"Y\n\x1fGenerateMqttCredentialsResponse\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x12\n\nexpires_at\x18\x03 \x01(\x03\"U\n\x19UpdateDeviceStatusRequest\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12%\n\x06status\x18\x02 \x01(\x0e\x32\x15.devices.DeviceStatus\"-\n\x1aUpdateDeviceStatusResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"/\n\x1b\x44\x65leteDevicesByPlaceRequest\x12\x10\n\x08place_id\x18\x01 \x01(\t\"Z\n\x1c\x44\x65leteDevicesByPlaceResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rdeleted_count\x18\x02 \x01(\x05\x12\x12\n\ndevice_ids\x18\x03 \x03(\t\"\x19\n\x17GetAllThresholdsRequest\"\x87\x01\n\x14SensorWithThresholds\x12\x11\n\tsensor_id\x18\x01 \x01(\t\x12\x11\n\tdevice_id\x18\x02 \x01(\t\x12\x10\n\x08place_id\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12*\n\nthresholds\x18\x05 \x03(\x0b\x32\x16.devices.ThresholdInfo\"J\n\x18GetAllThresholdsResponse\x12.\n\x07sensors\x18\x01 \x03(\x0b\x32\x1d.devices.SensorWithThresholds\"4\n InvalidateMqttCredentialsRequest\x12\x10\n\x08user_ids\x18\x01 \x03(\t\"4\n!InvalidateMqttCredentialsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08*b\n\x0c\x44\x65viceStatus\x12\x1d\n\x19\x44\x45VICE_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14\x44\x45VICE_STATUS_ONLINE\x10\x01\x12\x19\n\x15\x44\x45VICE_STATUS_OFFLINE\x10\x02*k\n\tValueType\x12\x1a\n\x16VALUE_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11VALUE_TYPE_NUMBER\x10\x01\x12\x16\n\x12VALUE_TYPE_BOOLEAN\x10\x02\x12\x13\n\x0fVALUE_TYPE_ENUM\x10\x03*_\n\rThresholdType\x12\x1e\n\x1aTHRESHOLD_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12THRESHOLD_TYPE_MIN\x10\x01\x12\x16\n\x12THRESHOLD_TYPE_MAX\x10\x02*x\n\x11ThresholdSeverity\x12\"\n\x1eTHRESHOLD_SEVERITY_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTHRESHOLD_SEVERITY_WARNING\x10\x01\x12\x1f\n\x1bTHRESHOLD_SEVERITY_CRITICAL\x10\x02\x32\xba\x11\n\x0e\x44\x65vicesService\x12K\n\x0c\x43reateDevice\x12\x1c.devices.CreateDeviceRequest\x1a\x1d.devices.CreateDeviceResponse\x12\x42\n\tGetDevice\x12\x19.devices.GetDeviceRequest\x1a\x1a.devices.GetDeviceResponse\x12H\n\x0bListDevices\x12\x1b.devices.ListDevicesRequest\x1a\x1c.devices.ListDevicesResponse\x12K\n\x0cUpdateDevice\x12\x1c.devices.UpdateDeviceRequest\x1a\x1d.devices.UpdateDeviceResponse\x12K\n\x0c\x44\x65leteDevice\x12\x1c.devices.DeleteDeviceRequest\x1a\x1d.devices.DeleteDeviceResponse\x12\x66\n\x15RegenerateDeviceToken\x12%.devices.RegenerateDeviceTokenRequest\x1a&.devices.RegenerateDeviceTokenResponse\x12K\n\x0c\x43reateSensor\x12\x1c.devices.CreateSensorRequest\x1a\x1d.devices.CreateSensorResponse\x12H\n\x0bListSensors\x12\x1b.devices.ListSensorsRequest\x1a\x1c.devices.ListSensorsResponse\x12K\n\x0cUpdateSensor\x12\x1c.devices.UpdateSensorRequest\x1a\x1d.devices.UpdateSensorResponse\x12K\n\x0c\x44\x65leteSensor\x12\x1c.devices.DeleteSensorRequest\x1a\x1d.devices.DeleteSensorResponse\x12K\n\x0cSetThreshold\x12\x1c.devices.SetThresholdRequest\x1a\x1d.devices.SetThresholdResponse\x12Q\n\x0eListThresholds\x12\x1e.devices.ListThresholdsRequest\x1a\x1f.devices.ListThresholdsResponse\x12T\n\x0f\x44\x65leteThreshold\x12\x1f.devices.DeleteThresholdRequest\x1a .devices.DeleteThresholdResponse\x12`\n\x13GetSensorThresholds\x12#.devices.GetSensorThresholdsRequest\x1a$.devices.GetSensorThresholdsResponse\x12Q\n\x0e\x43reateActuator\x12\x1e.devices.CreateActuatorRequest\x1a\x1f.devices.CreateActuatorResponse\x12N\n\rListActuators\x12\x1d.devices.ListActuatorsRequest\x1a\x1e.devices.ListActuatorsResponse\x12Q\n\x0eUpdateActuator\x12\x1e.devices.UpdateActuatorRequest\x1a\x1f.devices.UpdateActuatorResponse\x12Q\n\x0e\x44\x65leteActuator\x12\x1e.devices.DeleteActuatorRequest\x1a\x1f.devices.DeleteActuatorResponse\x12H\n\x0bSendCommand\x12\x1b.devices.SendCommandRequest\x1a\x1c.devices.SendCommandResponse\x12]\n\x12\x41uthenticateDevice\x12\".devices.AuthenticateDeviceRequest\x1a#.devices.AuthenticateDeviceResponse\x12Q\n\x0e\x43heckDeviceAcl\x12\x1e.devices.CheckDeviceAclRequest\x1a\x1f.devices.CheckDeviceAclResponse\x12l\n\x17GenerateMqttCredentials\x12\'.devices.GenerateMqttCredentialsRequest\x1a(.devices.GenerateMqttCredentialsResponse\x12]\n\x12UpdateDeviceStatus\x12\".devices.UpdateDeviceStatusRequest\x1a#.devices.UpdateDeviceStatusResponse\x12\x63\n\x14\x44\x65leteDevicesByPlace\x12$.devices.DeleteDevicesByPlaceRequest\x1a%.devices.DeleteDevicesByPlaceResponse\x12r\n\x19InvalidateMqttCredentials\x12).devices.InvalidateMqttCredentialsRequest\x1a*.devices.InvalidateMqttCredentialsResponse\x12W\n\x10GetAllThresholds\x12 .devices.GetAllThresholdsRequest\x1a!.devices.GetAllThresholdsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'devices_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DEVICESTATUS']._serialized_start=5179
  _globals['_DEVICESTATUS']._serialized_end=5277
  _globals['_VALUETYPE']._serialized_start=5279
  _globals['_VALUETYPE']._serialized_end=5386
  _globals['_THRESHOLDTYPE']._serialized_start=5388
  _globals['_THRESHOLDTYPE']._serialized_end=5483
  _globals['_THRESHOLDSEVERITY']._serialized_start=5485
  _globals['_THRESHOLDSEVERITY']._serialized_end=5605
  _globals['_DEVICEINFO']._serialized_start=27
  _globals['_DEVICEINFO']._serialized_end=271
  _globals['_DEVICESUMMARY']._serialized_start=273
  _globals['_DEVICESUMMARY']._serialized_end=400
  _globals['_CREATEDEVICEREQUEST']._serialized_start=402
  _globals['_CREATEDEVICEREQUEST']._serialized_end=472
  _globals['_CREATEDEVICERESPONSE']._serialized_start=474
  _globals['_CREATEDEVICERESPONSE']._serialized_end=530
  _globals['_GETDEVICEREQUEST']._serialized_start=532
  _globals['_GETDEVICEREQUEST']._serialized_end=604
  _globals['_GETDEVICERESPONSE']._serialized_start=606
  _globals['_GETDEVICERESPONSE']._serialized_end=662
  _globals['_LISTDEVICESREQUEST']._serialized_start=664
  _globals['_LISTDEVICESREQUEST']._serialized_end=751
  _globals['_LISTDEVICESRESPONSE']._serialized_start=753
  _globals['_LISTDEVICESRESPONSE']._serialized_end=830
  _globals['_UPDATEDEVICEREQUEST']._serialized_start=832
  _globals['_UPDATEDEVICEREQUEST']._serialized_end=921
  _globals['_UPDATEDEVICERESPONSE']._serialized_start=923
  _globals['_UPDATEDEVICERESPONSE']._serialized_end=964
  _globals['_DELETEDEVICEREQUEST']._serialized_start=966
  _globals['_DELETEDEVICEREQUEST']._serialized_end=1041
  _globals['_DELETEDEVICERESPONSE']._serialized_start=1043
  _globals['_DELETEDEVICERESPONSE']._serialized_end=1082
  _globals['_REGENERATEDEVICETOKENREQUEST']._serialized_start=1084
  _globals['_REGENERATEDEVICETOKENREQUEST']._serialized_end=1168
  _globals['_REGENERATEDEVICETOKENRESPONSE']._serialized_start=1170
  _globals['_REGENERATEDEVICETOKENRESPONSE']._serialized_end=1216
  _globals['_SENSORINFO']._serialized_start=1219
  _globals['_SENSORINFO']._serialized_end=1375
  _globals['_CREATESENSORREQUEST']._serialized_start=1378
  _globals['_CREATESENSORREQUEST']._serialized_end=1559
  _globals['_CREATESENSORRESPONSE']._serialized_start=1561
  _globals['_CREATESENSORRESPONSE']._serialized_end=1602
  _globals['_LISTSENSORSREQUEST']._serialized_start=1604
  _globals['_LISTSENSORSREQUEST']._serialized_end=1678
  _globals['_LISTSENSORSRESPONSE']._serialized_start=1680
  _globals['_LISTSENSORSRESPONSE']._serialized_end=1739
  _globals['_UPDATESENSORREQUEST']._serialized_start=1742
  _globals['_UPDATESENSORREQUEST']._serialized_end=1889
  _globals['_UPDATESENSORRESPONSE']._serialized_start=1891
  _globals['_UPDATESENSORRESPONSE']._serialized_end=1932
  _globals['_DELETESENSORREQUEST']._serialized_start=1934
  _globals['_DELETESENSORREQUEST']._serialized_end=2028
  _globals['_DELETESENSORRESPONSE']._serialized_start=2030
  _globals['_DELETESENSORRESPONSE']._serialized_end=2069
  _globals['_THRESHOLDINFO']._serialized_start=2072
  _globals['_THRESHOLDINFO']._serialized_end=2227
  _globals['_SETTHRESHOLDREQUEST']._serialized_start=2230
  _globals['_SETTHRESHOLDREQUEST']._serialized_end=2423
  _globals['_SETTHRESHOLDRESPONSE']._serialized_start=2425
  _globals['_SETTHRESHOLDRESPONSE']._serialized_end=2469
  _globals['_LISTTHRESHOLDSREQUEST']._serialized_start=2471
  _globals['_LISTTHRESHOLDSREQUEST']._serialized_end=2567
  _globals['_LISTTHRESHOLDSRESPONSE']._serialized_start=2569
  _globals['_LISTTHRESHOLDSRESPONSE']._serialized_end=2637
  _globals['_DELETETHRESHOLDREQUEST']._serialized_start=2639
  _globals['_DELETETHRESHOLDREQUEST']._serialized_end=2758
  _globals['_DELETETHRESHOLDRESPONSE']._serialized_start=2760
  _globals['_DELETETHRESHOLDRESPONSE']._serialized_end=2802
  _globals['_GETSENSORTHRESHOLDSREQUEST']._serialized_start=2804
  _globals['_GETSENSORTHRESHOLDSREQUEST']._serialized_end=2851
  _globals['_GETSENSORTHRESHOLDSRESPONSE']._serialized_start=2853
  _globals['_GETSENSORTHRESHOLDSRESPONSE']._serialized_end=2926
  _globals['_ACTUATORINFO']._serialized_start=2929
  _globals['_ACTUATORINFO']._serialized_end=3163
  _globals['_CREATEACTUATORREQUEST']._serialized_start=3166
  _globals['_CREATEACTUATORREQUEST']._serialized_end=3423
  _globals['_CREATEACTUATORRESPONSE']._serialized_start=3425
  _globals['_CREATEACTUATORRESPONSE']._serialized_end=3470
  _globals['_LISTACTUATORSREQUEST']._serialized_start=3472
  _globals['_LISTACTUATORSREQUEST']._serialized_end=3548
  _globals['_LISTACTUATORSRESPONSE']._serialized_start=3550
  _globals['_LISTACTUATORSRESPONSE']._serialized_end=3615
  _globals['_UPDATEACTUATORREQUEST']._serialized_start=3618
  _globals['_UPDATEACTUATORREQUEST']._serialized_end=3843
  _globals['_UPDATEACTUATORRESPONSE']._serialized_start=3845
  _globals['_UPDATEACTUATORRESPONSE']._serialized_end=3890
  _globals['_DELETEACTUATORREQUEST']._serialized_start=3892
  _globals['_DELETEACTUATORREQUEST']._serialized_end=3990
  _globals['_DELETEACTUATORRESPONSE']._serialized_start=3992
  _globals['_DELETEACTUATORRESPONSE']._serialized_end=4033
  _globals['_SENDCOMMANDREQUEST']._serialized_start=4035
  _globals['_SENDCOMMANDREQUEST']._serialized_end=4146
  _globals['_SENDCOMMANDRESPONSE']._serialized_start=4148
  _globals['_SENDCOMMANDRESPONSE']._serialized_end=4186
  _globals['_AUTHENTICATEDEVICEREQUEST']._serialized_start=4188
  _globals['_AUTHENTICATEDEVICEREQUEST']._serialized_end=4251
  _globals['_AUTHENTICATEDEVICERESPONSE']._serialized_start=4253
  _globals['_AUTHENTICATEDEVICERESPONSE']._serialized_end=4296
  _globals['_CHECKDEVICEACLREQUEST']._serialized_start=4298
  _globals['_CHECKDEVICEACLREQUEST']._serialized_end=4370
  _globals['_CHECKDEVICEACLRESPONSE']._serialized_start=4372
  _globals['_CHECKDEVICEACLRESPONSE']._serialized_end=4411
  _globals['_GENERATEMQTTCREDENTIALSREQUEST']._serialized_start=4413
  _globals['_GENERATEMQTTCREDENTIALSREQUEST']._serialized_end=4462
  _globals['_GENERATEMQTTCREDENTIALSRESPONSE']._serialized_start=4464
  _globals['_GENERATEMQTTCREDENTIALSRESPONSE']._serialized_end=4553
  _globals['_UPDATEDEVICESTATUSREQUEST']._serialized_start=4555
  _globals['_UPDATEDEVICESTATUSREQUEST']._serialized_end=4640
  _globals['_UPDATEDEVICESTATUSRESPONSE']._serialized_start=4642
  _globals['_UPDATEDEVICESTATUSRESPONSE']._serialized_end=4687
  _globals['_DELETEDEVICESBYPLACEREQUEST']._serialized_start=4689
  _globals['_DELETEDEVICESBYPLACEREQUEST']._serialized_end=4736
  _globals['_DELETEDEVICESBYPLACERESPONSE']._serialized_start=4738
  _globals['_DELETEDEVICESBYPLACERESPONSE']._serialized_end=4828
  _globals['_GETALLTHRESHOLDSREQUEST']._serialized_start=4830
  _globals['_GETALLTHRESHOLDSREQUEST']._serialized_end=4855
  _globals['_SENSORWITHTHRESHOLDS']._serialized_start=4858
  _globals['_SENSORWITHTHRESHOLDS']._serialized_end=4993
  _globals['_GETALLTHRESHOLDSRESPONSE']._serialized_start=4995
  _globals['_GETALLTHRESHOLDSRESPONSE']._serialized_end=5069
  _globals['_INVALIDATEMQTTCREDENTIALSREQUEST']._serialized_start=5071
  _globals['_INVALIDATEMQTTCREDENTIALSREQUEST']._serialized_end=5123
  _globals['_INVALIDATEMQTTCREDENTIALSRESPONSE']._serialized_start=5125
  _globals['_INVALIDATEMQTTCREDENTIALSRESPONSE']._serialized_end=5177
  _globals['_DEVICESSERVICE']._serialized_start=5608
  _globals['_DEVICESSERVICE']._serialized_end=7842
# @@protoc_insertion_point(module_scope)
