"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import auth_pb2
import collections.abc
import grpc
import grpc.aio
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class AuthServiceStub:
    @typing.overload
    def __new__(cls, channel: grpc.Channel) -> AuthServiceStub: ...
    @typing.overload
    def __new__(cls, channel: grpc.aio.Channel) -> AuthServiceAsyncStub: ...
    Register: grpc.UnaryUnaryMultiCallable[auth_pb2.RegisterRequest, auth_pb2.RegisterResponse]
    Login: grpc.UnaryUnaryMultiCallable[auth_pb2.LoginRequest, auth_pb2.LoginResponse]
    RefreshTokens: grpc.UnaryUnaryMultiCallable[auth_pb2.RefreshTokensRequest, auth_pb2.RefreshTokensResponse]
    Logout: grpc.UnaryUnaryMultiCallable[auth_pb2.LogoutRequest, auth_pb2.LogoutResponse]
    GetMe: grpc.UnaryUnaryMultiCallable[auth_pb2.GetMeRequest, auth_pb2.GetMeResponse]
    GetUserByEmail: grpc.UnaryUnaryMultiCallable[auth_pb2.GetUserByEmailRequest, auth_pb2.GetUserByEmailResponse]
    ValidateToken: grpc.UnaryUnaryMultiCallable[auth_pb2.ValidateTokenRequest, auth_pb2.ValidateTokenResponse]
    SendOtp: grpc.UnaryUnaryMultiCallable[auth_pb2.SendOtpRequest, auth_pb2.SendOtpResponse]
    VerifyOtp: grpc.UnaryUnaryMultiCallable[auth_pb2.VerifyOtpRequest, auth_pb2.VerifyOtpResponse]

@typing.type_check_only
class AuthServiceAsyncStub(AuthServiceStub):
    def __init__(self, channel: grpc.aio.Channel) -> None: ...
    Register: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.RegisterRequest, auth_pb2.RegisterResponse]  # type: ignore[assignment]
    Login: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.LoginRequest, auth_pb2.LoginResponse]  # type: ignore[assignment]
    RefreshTokens: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.RefreshTokensRequest, auth_pb2.RefreshTokensResponse]  # type: ignore[assignment]
    Logout: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.LogoutRequest, auth_pb2.LogoutResponse]  # type: ignore[assignment]
    GetMe: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.GetMeRequest, auth_pb2.GetMeResponse]  # type: ignore[assignment]
    GetUserByEmail: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.GetUserByEmailRequest, auth_pb2.GetUserByEmailResponse]  # type: ignore[assignment]
    ValidateToken: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.ValidateTokenRequest, auth_pb2.ValidateTokenResponse]  # type: ignore[assignment]
    SendOtp: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.SendOtpRequest, auth_pb2.SendOtpResponse]  # type: ignore[assignment]
    VerifyOtp: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.VerifyOtpRequest, auth_pb2.VerifyOtpResponse]  # type: ignore[assignment]

class AuthServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Register(
        self,
        request: auth_pb2.RegisterRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.RegisterResponse, collections.abc.Awaitable[auth_pb2.RegisterResponse]]: ...

    @abc.abstractmethod
    def Login(
        self,
        request: auth_pb2.LoginRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.LoginResponse, collections.abc.Awaitable[auth_pb2.LoginResponse]]: ...

    @abc.abstractmethod
    def RefreshTokens(
        self,
        request: auth_pb2.RefreshTokensRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.RefreshTokensResponse, collections.abc.Awaitable[auth_pb2.RefreshTokensResponse]]: ...

    @abc.abstractmethod
    def Logout(
        self,
        request: auth_pb2.LogoutRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.LogoutResponse, collections.abc.Awaitable[auth_pb2.LogoutResponse]]: ...

    @abc.abstractmethod
    def GetMe(
        self,
        request: auth_pb2.GetMeRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.GetMeResponse, collections.abc.Awaitable[auth_pb2.GetMeResponse]]: ...

    @abc.abstractmethod
    def GetUserByEmail(
        self,
        request: auth_pb2.GetUserByEmailRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.GetUserByEmailResponse, collections.abc.Awaitable[auth_pb2.GetUserByEmailResponse]]: ...

    @abc.abstractmethod
    def ValidateToken(
        self,
        request: auth_pb2.ValidateTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.ValidateTokenResponse, collections.abc.Awaitable[auth_pb2.ValidateTokenResponse]]: ...

    @abc.abstractmethod
    def SendOtp(
        self,
        request: auth_pb2.SendOtpRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.SendOtpResponse, collections.abc.Awaitable[auth_pb2.SendOtpResponse]]: ...

    @abc.abstractmethod
    def VerifyOtp(
        self,
        request: auth_pb2.VerifyOtpRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.VerifyOtpResponse, collections.abc.Awaitable[auth_pb2.VerifyOtpResponse]]: ...

def add_AuthServiceServicer_to_server(servicer: AuthServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
