"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import collector_pb2
import grpc
import grpc.aio
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class CollectorServiceStub:
    @typing.overload
    def __new__(cls, channel: grpc.Channel) -> CollectorServiceStub: ...
    @typing.overload
    def __new__(cls, channel: grpc.aio.Channel) -> CollectorServiceAsyncStub: ...
    GetLatestReadings: grpc.UnaryUnaryMultiCallable[collector_pb2.GetLatestReadingsRequest, collector_pb2.GetLatestReadingsResponse]
    DeleteReadings: grpc.UnaryUnaryMultiCallable[collector_pb2.DeleteReadingsRequest, collector_pb2.DeleteReadingsResponse]
    GetReadings: grpc.UnaryUnaryMultiCallable[collector_pb2.GetReadingsRequest, collector_pb2.GetReadingsResponse]

@typing.type_check_only
class CollectorServiceAsyncStub(CollectorServiceStub):
    def __init__(self, channel: grpc.aio.Channel) -> None: ...
    GetLatestReadings: grpc.aio.UnaryUnaryMultiCallable[collector_pb2.GetLatestReadingsRequest, collector_pb2.GetLatestReadingsResponse]  # type: ignore[assignment]
    DeleteReadings: grpc.aio.UnaryUnaryMultiCallable[collector_pb2.DeleteReadingsRequest, collector_pb2.DeleteReadingsResponse]  # type: ignore[assignment]
    GetReadings: grpc.aio.UnaryUnaryMultiCallable[collector_pb2.GetReadingsRequest, collector_pb2.GetReadingsResponse]  # type: ignore[assignment]

class CollectorServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetLatestReadings(
        self,
        request: collector_pb2.GetLatestReadingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[collector_pb2.GetLatestReadingsResponse, collections.abc.Awaitable[collector_pb2.GetLatestReadingsResponse]]: ...

    @abc.abstractmethod
    def DeleteReadings(
        self,
        request: collector_pb2.DeleteReadingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[collector_pb2.DeleteReadingsResponse, collections.abc.Awaitable[collector_pb2.DeleteReadingsResponse]]: ...

    @abc.abstractmethod
    def GetReadings(
        self,
        request: collector_pb2.GetReadingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[collector_pb2.GetReadingsResponse, collections.abc.Awaitable[collector_pb2.GetReadingsResponse]]: ...

def add_CollectorServiceServicer_to_server(servicer: CollectorServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
