"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Role:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Role.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ROLE_UNSPECIFIED: _Role.ValueType  # 0
    ROLE_OWNER: _Role.ValueType  # 1
    ROLE_ADMIN: _Role.ValueType  # 2
    ROLE_VIEWER: _Role.ValueType  # 3

class Role(_Role, metaclass=_RoleEnumTypeWrapper): ...

ROLE_UNSPECIFIED: Role.ValueType  # 0
ROLE_OWNER: Role.ValueType  # 1
ROLE_ADMIN: Role.ValueType  # 2
ROLE_VIEWER: Role.ValueType  # 3
Global___Role: typing_extensions.TypeAlias = Role

@typing.final
class CreatePlaceRequest(google.protobuf.message.Message):
    """--- Places ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    name: builtins.str
    description: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["description", b"description", "name", b"name", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreatePlaceRequest: typing_extensions.TypeAlias = CreatePlaceRequest

@typing.final
class CreatePlaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACE_ID_FIELD_NUMBER: builtins.int
    place_id: builtins.str
    def __init__(
        self,
        *,
        place_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreatePlaceResponse: typing_extensions.TypeAlias = CreatePlaceResponse

@typing.final
class GetPlaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetPlaceRequest: typing_extensions.TypeAlias = GetPlaceRequest

@typing.final
class GetPlaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    USER_ROLE_FIELD_NUMBER: builtins.int
    place_id: builtins.str
    name: builtins.str
    description: builtins.str
    user_role: Global___Role.ValueType
    def __init__(
        self,
        *,
        place_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        user_role: Global___Role.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["description", b"description", "name", b"name", "place_id", b"place_id", "user_role", b"user_role"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetPlaceResponse: typing_extensions.TypeAlias = GetPlaceResponse

@typing.final
class ListPlacesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListPlacesRequest: typing_extensions.TypeAlias = ListPlacesRequest

@typing.final
class ListPlacesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACES_FIELD_NUMBER: builtins.int
    @property
    def places(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___PlaceSummary]: ...
    def __init__(
        self,
        *,
        places: collections.abc.Iterable[Global___PlaceSummary] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["places", b"places"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListPlacesResponse: typing_extensions.TypeAlias = ListPlacesResponse

@typing.final
class PlaceSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    USER_ROLE_FIELD_NUMBER: builtins.int
    place_id: builtins.str
    name: builtins.str
    description: builtins.str
    user_role: Global___Role.ValueType
    def __init__(
        self,
        *,
        place_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        user_role: Global___Role.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["description", b"description", "name", b"name", "place_id", b"place_id", "user_role", b"user_role"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___PlaceSummary: typing_extensions.TypeAlias = PlaceSummary

@typing.final
class UpdatePlaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    name: builtins.str
    description: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["description", b"description", "name", b"name", "place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdatePlaceRequest: typing_extensions.TypeAlias = UpdatePlaceRequest

@typing.final
class UpdatePlaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACE_ID_FIELD_NUMBER: builtins.int
    place_id: builtins.str
    def __init__(
        self,
        *,
        place_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdatePlaceResponse: typing_extensions.TypeAlias = UpdatePlaceResponse

@typing.final
class DeletePlaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeletePlaceRequest: typing_extensions.TypeAlias = DeletePlaceRequest

@typing.final
class DeletePlaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeletePlaceResponse: typing_extensions.TypeAlias = DeletePlaceResponse

@typing.final
class AddMemberRequest(google.protobuf.message.Message):
    """--- Members ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    TARGET_USER_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    target_user_id: builtins.str
    role: Global___Role.ValueType
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        target_user_id: builtins.str = ...,
        role: Global___Role.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id", "role", b"role", "target_user_id", b"target_user_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___AddMemberRequest: typing_extensions.TypeAlias = AddMemberRequest

@typing.final
class AddMemberResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___AddMemberResponse: typing_extensions.TypeAlias = AddMemberResponse

@typing.final
class RemoveMemberRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    TARGET_USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    target_user_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        target_user_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id", "target_user_id", b"target_user_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RemoveMemberRequest: typing_extensions.TypeAlias = RemoveMemberRequest

@typing.final
class RemoveMemberResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RemoveMemberResponse: typing_extensions.TypeAlias = RemoveMemberResponse

@typing.final
class UpdateMemberRoleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    TARGET_USER_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    target_user_id: builtins.str
    role: Global___Role.ValueType
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        target_user_id: builtins.str = ...,
        role: Global___Role.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id", "role", b"role", "target_user_id", b"target_user_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateMemberRoleRequest: typing_extensions.TypeAlias = UpdateMemberRoleRequest

@typing.final
class UpdateMemberRoleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateMemberRoleResponse: typing_extensions.TypeAlias = UpdateMemberRoleResponse

@typing.final
class ListMembersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListMembersRequest: typing_extensions.TypeAlias = ListMembersRequest

@typing.final
class ListMembersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMBERS_FIELD_NUMBER: builtins.int
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___MemberInfo]: ...
    def __init__(
        self,
        *,
        members: collections.abc.Iterable[Global___MemberInfo] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["members", b"members"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListMembersResponse: typing_extensions.TypeAlias = ListMembersResponse

@typing.final
class MemberInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    role: Global___Role.ValueType
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        role: Global___Role.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["role", b"role", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MemberInfo: typing_extensions.TypeAlias = MemberInfo
